==> libktorrent-24.12.0-1-x86_64.pkg.tar.zst: usr/lib/cmake/KTorrent6/KTorrent6Config.cmake <==

####### Expanded from @PACKAGE_INIT@ by configure_package_config_file() #######
####### Any changes to this file will be overwritten by the next CMake run ####
####### The input file was KTorrent6Config.cmake.in                            ########

get_filename_component(PACKAGE_PREFIX_DIR "${CMAKE_CURRENT_LIST_DIR}/../../../" ABSOLUTE)

# Use original install prefix when loaded through a "/usr move"
# cross-prefix symbolic link such as /lib -> /usr/lib.
get_filename_component(_realCurr "${CMAKE_CURRENT_LIST_DIR}" REALPATH)
get_filename_component(_realOrig "/usr/lib/cmake/KTorrent6" REALPATH)
if(_realCurr STREQUAL _realOrig)
  set(PACKAGE_PREFIX_DIR "/usr")
endif()
unset(_realOrig)
unset(_realCurr)

macro(set_and_check _var _file)
  set(${_var} "${_file}")
  if(NOT EXISTS "${_file}")
    message(FATAL_ERROR "File or directory ${_file} referenced by variable ${_var} does not exist !")
  endif()
endmacro()

macro(check_required_components _NAME)
  foreach(comp ${${_NAME}_FIND_COMPONENTS})
    if(NOT ${_NAME}_${comp}_FOUND)
      if(${_NAME}_FIND_REQUIRED_${comp})
        set(${_NAME}_FOUND FALSE)
      endif()
    endif()
  endforeach()
endmacro()

####################################################################################

set(CMAKE_MODULE_PATH ${CMAKE_CURRENT_LIST_DIR} ${CMAKE_MODULE_PATH})

find_dependency(KF6Archive "5.240.0")
find_dependency(KF6Config "5.240.0")
find_dependency(KF6KIO "5.240.0")

find_dependency(Qt6Core "6.5.0")
find_dependency(Qt6Network "6.5.0")
find_dependency(Qt6Core5Compat "6.5.0")

find_dependency(Boost "1.71.0")
find_dependency(LibGMP "6.0.0")
find_dependency(LibGcrypt "1.4.5")

include("${CMAKE_CURRENT_LIST_DIR}/KTorrent6Targets.cmake")

==> libktorrent-25.12.2-1-x86_64.pkg.tar.zst: usr/lib/cmake/KTorrent6/KTorrent6Config.cmake <==

####### Expanded from @PACKAGE_INIT@ by configure_package_config_file() #######
####### Any changes to this file will be overwritten by the next CMake run ####
####### The input file was KTorrent6Config.cmake.in                            ########

get_filename_component(PACKAGE_PREFIX_DIR "${CMAKE_CURRENT_LIST_DIR}/../../../" ABSOLUTE)

# Use original install prefix when loaded through a "/usr move"
# cross-prefix symbolic link such as /lib -> /usr/lib.
get_filename_component(_realCurr "${CMAKE_CURRENT_LIST_DIR}" REALPATH)
get_filename_component(_realOrig "/usr/lib/cmake/KTorrent6" REALPATH)
if(_realCurr STREQUAL _realOrig)
  set(PACKAGE_PREFIX_DIR "/usr")
endif()
unset(_realOrig)
unset(_realCurr)

macro(set_and_check _var _file)
  set(${_var} "${_file}")
  if(NOT EXISTS "${_file}")
    message(FATAL_ERROR "File or directory ${_file} referenced by variable ${_var} does not exist !")
  endif()
endmacro()

macro(check_required_components _NAME)
  foreach(comp ${${_NAME}_FIND_COMPONENTS})
    if(NOT ${_NAME}_${comp}_FOUND)
      if(${_NAME}_FIND_REQUIRED_${comp})
        set(${_NAME}_FOUND FALSE)
      endif()
    endif()
  endforeach()
endmacro()

####################################################################################

set(CMAKE_MODULE_PATH ${CMAKE_CURRENT_LIST_DIR} ${CMAKE_MODULE_PATH})

include(CMakeFindDependencyMacro)

find_dependency(KF6Archive "5.240.0")
find_dependency(KF6Config "5.240.0")
find_dependency(KF6KIO "5.240.0")

find_dependency(Qt6Core "6.5.0")
find_dependency(Qt6Network "6.5.0")

find_dependency(Boost "1.71.0")
find_dependency(LibGMP "6.0.0")
if ("1")
    find_dependency(OpenSSL "3.0.0")
endif()
if ("0")
    find_dependency(LibGcrypt "1.4.5")
endif()

include("${CMAKE_CURRENT_LIST_DIR}/KTorrent6Targets.cmake")
